<?php

/**
 * Prizm Pay - Core
 * 
 * This class contains some useful methods
 * 
 * @version 1.0
 */
class PrizmPayClient {

    /**
     * Make secret hash
     * 
     * @param int $merchantID
     * @param string $secretKey
     * @param string $data
     * @param int $timestamp
     * @return string
     */
    public static function secretHash($merchantID, $secretKey, $data, $timestamp) {

        return hash('sha256', $secretKey . $timestamp . $merchantID . $data);
    }

    /**
     * Get datafeed
     * 
     * @param int $merchantID
     * @param string $secretKey
     * @param int $expiry
     * @return boolean
     */
    public static function datafeed($merchantID, $secretKey, $expiry = 900) {

        $time = filter_input(INPUT_POST, 'time');

        // check timeout
        if ($time && (abs($time - time()) > $expiry)) {
            return FALSE;
        }

        $data = filter_input(INPUT_POST, 'data');
        $hash = filter_input(INPUT_POST, 'hash');

        // check secret hash
        $localHash = self::secretHash($merchantID, $secretKey, $data, $time);
        if ($localHash != $hash) {
            return FALSE;
        }

        // return decoded datafeed
        return json_decode($data, TRUE);
    }

}
